# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/litecms/leaderboard_ad/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Litecms\\LeaderboardAd\\": "packages/litecms/leaderboard_ad/src",
            "Litecms\\LeaderboardAd\\Seeders\\": "packages/litecms/leaderboard_ad/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Litecms\LeaderboardAd\Providers\LeaderboardAdServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'LeaderboardAd'  => Litecms\LeaderboardAd\Facades\LeaderboardAd::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Litecms\\LeaderboardAd\\Seeders\\LeaderboardAdTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Litecms\LeaderboardAd\Providers\LeaderboardAdServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Litecms\LeaderboardAd\Providers\LeaderboardAdServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Litecms\LeaderboardAd\Providers\LeaderboardAdServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/leaderboard_ad/{modulename}

**User**

    http://path-to-route-folder/user/leaderboard_ad/{modulename}

**Public**

    http://path-to-route-folder/leaderboard_ads


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/leaderboard_ad/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/leaderboard_ad/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/leaderboard_ad/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/leaderboard_ad/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/leaderboard_ad/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/leaderboard_ad/{modulename}/{slug}
    METHOD: GET