<?php

namespace Litecms\LeaderboardAd\Http\Controllers;

use Exception;
use Litepie\Http\Controllers\ResourceController as BaseController;
use Litepie\Repository\Filter\RequestFilter;
use Litecms\LeaderboardAd\Forms\LeaderboardAd as LeaderboardAdForm;
use Litecms\LeaderboardAd\Http\Requests\LeaderboardAdRequest;
use Litecms\LeaderboardAd\Interfaces\LeaderboardAdRepositoryInterface;
use Litecms\LeaderboardAd\Repositories\Eloquent\Filters\LeaderboardAdResourceFilter;
use Litecms\LeaderboardAd\Repositories\Eloquent\Presenters\LeaderboardAdListPresenter;

/**
 * Resource controller class for leaderboard_ad.
 */
class LeaderboardAdResourceController extends BaseController
{

    /**
     * Initialize leaderboard_ad resource controller.
     *
     *
     * @return null
     */
    public function __construct(LeaderboardAdRepositoryInterface $leaderboard_ad)
    {
        parent::__construct();
        $this->form = LeaderboardAdForm::setAttributes()->toArray();
        $this->modules = $this->modules(config('litecms.leaderboard_ad.modules'), 'leaderboard_ad', guard_url('leaderboard_ad'));
        $this->repository = $leaderboard_ad;
    }

    /**
     * Display a list of leaderboard_ad.
     *
     * @return Response
     */
    public function index(LeaderboardAdRequest $request)
    {

        $pageLimit = $request->input('pageLimit', config('database.pagination.limit'));
        $data = $this->repository
            ->pushFilter(RequestFilter::class)
            ->pushFilter(LeaderboardAdResourceFilter::class)
            ->setPresenter(LeaderboardAdListPresenter::class)
            ->simplePaginate($pageLimit)
            // ->withQueryString()
            ->toArray();

        extract($data);
        $form = $this->form;
        $modules = $this->modules;

        return $this->response->setMetaTitle(trans('leaderboard_ad::leaderboard_ad.names'))
            ->view('leaderboard_ad::leaderboard_ad.index')
            ->data(compact('data', 'meta', 'links', 'modules', 'form'))
            ->output();
    }

    /**
     * Display leaderboard_ad.
     *
     * @param Request $request
     * @param Model   $leaderboard_ad
     *
     * @return Response
     */
    public function show(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response
            ->setMetaTitle(trans('app.view') . ' ' . trans('leaderboard_ad::leaderboard_ad.name'))
            ->data(compact('data', 'form', 'modules', 'form'))
            ->view('leaderboard_ad::leaderboard_ad.show')
            ->output();
    }

    /**
     * Show the form for creating a new leaderboard_ad.
     *
     * @param Request $request
     *x
     * @return Response
     */
    public function create(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();
        return $this->response->setMetaTitle(trans('app.new') . ' ' . trans('leaderboard_ad::leaderboard_ad.name'))
            ->view('leaderboard_ad::leaderboard_ad.create')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Create new leaderboard_ad.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $attributes['user_id'] = user_id();
            $attributes['user_type'] = user_type();
            $repository->create($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.created', ['Module' => trans('leaderboard_ad::leaderboard_ad.name')]))
                ->code(204)
                ->data(compact('data'))
                ->status('success')
                ->url(guard_url('leaderboard_ad/leaderboard_ad/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/leaderboard_ad/leaderboard_ad'))
                ->redirect();
        }

    }

    /**
     * Show leaderboard_ad for editing.
     *
     * @param Request $request
     * @param Model   $leaderboard_ad
     *
     * @return Response
     */
    public function edit(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        $form = $this->form;
        $modules = $this->modules;
        $data = $repository->toArray();

        return $this->response->setMetaTitle(trans('app.edit') . ' ' . trans('leaderboard_ad::leaderboard_ad.name'))
            ->view('leaderboard_ad::leaderboard_ad.edit')
            ->data(compact('data', 'form', 'modules'))
            ->output();
    }

    /**
     * Update the leaderboard_ad.
     *
     * @param Request $request
     * @param Model   $leaderboard_ad
     *
     * @return Response
     */
    public function update(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        try {
            $attributes = $request->all();
            $repository->update($attributes);
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.updated', ['Module' => trans('leaderboard_ad::leaderboard_ad.name')]))
                ->code(204)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('leaderboard_ad/leaderboard_ad/' . $data['id']))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leaderboard_ad/leaderboard_ad/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the leaderboard_ad.
     *
     * @param Model   $leaderboard_ad
     *
     * @return Response
     */
    public function destroy(LeaderboardAdRequest $request, LeaderboardAdRepositoryInterface $repository)
    {
        try {
            $repository->delete();
            $data = $repository->toArray();

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('leaderboard_ad::leaderboard_ad.name')]))
                ->code(202)
                ->status('success')
                ->data(compact('data'))
                ->url(guard_url('leaderboard_ad/leaderboard_ad/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('leaderboard_ad/leaderboard_ad/' .  $repository->getRouteKey()))
                ->redirect();
        }

    }
}
