<?php

namespace Litecms\LeaderboardAd\Policies;

use Litepie\User\Interfaces\UserPolicyInterface;
use Litecms\LeaderboardAd\Models\LeaderboardAd;

class LeaderboardAdPolicy
{

    /**
     * Determine if the given user can view the leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     * @param LeaderboardAd $leaderboard_ad
     *
     * @return bool
     */
    public function view(UserPolicyInterface $authUser, LeaderboardAd $leaderboard_ad)
    {
        if ($authUser->canDo('leaderboard_ad.leaderboard_ad.view') && $authUser->isAdmin()) {
            return true;
        }

        return $leaderboard_ad->user_id == user_id() && $leaderboard_ad->user_type == user_type();
    }

    /**
     * Determine if the given user can create a leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function create(UserPolicyInterface $authUser)
    {
        return  $authUser->canDo('leaderboard_ad.leaderboard_ad.create');
    }

    /**
     * Determine if the given user can update the given leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     * @param LeaderboardAd $leaderboard_ad
     *
     * @return bool
     */
    public function update(UserPolicyInterface $authUser, LeaderboardAd $leaderboard_ad)
    {
        if ($authUser->canDo('leaderboard_ad.leaderboard_ad.edit') && $authUser->isAdmin()) {
            return true;
        }

        return $leaderboard_ad->user_id == user_id() && $leaderboard_ad->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function destroy(UserPolicyInterface $authUser, LeaderboardAd $leaderboard_ad)
    {
        return $leaderboard_ad->user_id == user_id() && $leaderboard_ad->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function verify(UserPolicyInterface $authUser, LeaderboardAd $leaderboard_ad)
    {
        if ($authUser->canDo('leaderboard_ad.leaderboard_ad.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given leaderboard_ad.
     *
     * @param UserPolicyInterface $authUser
     *
     * @return bool
     */
    public function approve(UserPolicyInterface $authUser, LeaderboardAd $leaderboard_ad)
    {
        if ($authUser->canDo('leaderboard_ad.leaderboard_ad.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $authUser    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($authUser, $ability)
    {
        if ($authUser->isSuperuser()) {
            return true;
        }
    }
}
