<?php

namespace Litecms\LeaderboardAd\Providers;

use Illuminate\Support\ServiceProvider;
use Litecms\LeaderboardAd\LeaderboardAds;

class LeaderboardAdServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = true;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'leaderboard_ad');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'leaderboard_ad');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->mergeConfig();
        $this->registerFacade();
        $this->registerBindings();
        //$this->registerCommands();

        $this->app->register(\Litecms\LeaderboardAd\Providers\AuthServiceProvider::class);
        $this->app->register(\Litecms\LeaderboardAd\Providers\RouteServiceProvider::class);
        // $this->app->register(\Litecms\LeaderboardAd\Providers\EventServiceProvider::class);
        // $this->app->register(\Litecms\LeaderboardAd\Providers\WorkflowServiceProvider::class);
    }

    /**
     * Register the vault facade without the user having to add it to the app.php file.
     *
     * @return void
     */
    public function registerFacade() {
        $this->app->bind('litecms.leaderboard_ad', function($app)
        {
            return $this->app->make(LeaderboardAds::class);
        });
    }

    /**
     * Register the bindings for the service provider.
     *
     * @return void
     */
    public function registerBindings() {
                // Bind LeaderboardAd to repository
        $this->app->bind(
            'Litecms\LeaderboardAd\Interfaces\LeaderboardAdRepositoryInterface',
            \Litecms\LeaderboardAd\Repositories\Eloquent\LeaderboardAdRepository::class
        );
    }


    /**
     * Merges user's and leaderboard_ad's configs.
     *
     * @return void
     */
    protected function mergeConfig()
    {
        $this->mergeConfigFrom(
            __DIR__ . '/../../config/config.php', 'litecms.leaderboard_ad'
        );
    }

    /**
     * Register scaffolding command
     */
    protected function registerCommands()
    {
        if ($this->app->runningInConsole()) {
            $this->commands([
                \Litecms\LeaderboardAd\Commands\LeaderboardAd::class,
            ]);
        }
    }
    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.leaderboard_ad'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/leaderboard_ad.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/leaderboard_ad')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/leaderboard_ad')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
